package com.rwk.system.service;

import java.util.List;
import java.util.Map;
import com.rwk.system.domain.RwkStaffInformation;

/**
 * 人员信息Service接口
 *
 * @author rick
 * @date 2024-11-25
 */
public interface IRwkStaffInformationService
{
    /**
     * 查询人员信息
     *
     * @param id 人员信息主键
     * @return 人员信息
     */
    public RwkStaffInformation selectRwkStaffInformationById(Long id);

    /**
     * 查询人员信息列表
     *
     * @param rwkStaffInformation 人员信息
     * @return 人员信息集合
     */
    public List<RwkStaffInformation> selectRwkStaffInformationList(RwkStaffInformation rwkStaffInformation);

    /**
     * 新增人员信息
     *
     * @param rwkStaffInformation 人员信息
     * @return 结果
     */
    public int insertRwkStaffInformation(RwkStaffInformation rwkStaffInformation);

    /**
     * 修改人员信息
     *
     * @param rwkStaffInformation 人员信息
     * @return 结果
     */
    public int updateRwkStaffInformation(RwkStaffInformation rwkStaffInformation);

    /**
     * 批量删除人员信息
     *
     * @param ids 需要删除的人员信息主键集合
     * @return 结果
     */
    public int deleteRwkStaffInformationByIds(String ids);

    /**
     * 删除人员信息信息
     *
     * @param id 人员信息主键
     * @return 结果
     */
    public int deleteRwkStaffInformationById(Long id);

    /**
     * 按照职务层级统计人数
     */
    public List<Map<String, Object>> selectTotalByJob();

    /**
     * 按照党派统计人数
     */
    public List<Map<String, Object>> selectTotalByParty();

    /**
     * 按照性别、年龄统计人数
     */
    public List<Map<String, Object>> selectTotalByAge();

    /**
     * 按照单位类别统计人数
     */
    public List<Map<String, Object>> selectTotalByUnitAttribute();

    /**
     * 按照全日制学历统计人数
     */
    public List<Map<String, Object>> selectTotalByQrzQualification();

    /**
     * 按照全日制学位统计人数
     */
    public List<Map<String, Object>> selectTotalByQrzDegree();

    /**
     * 按照在职学历统计人数
     */
    public List<Map<String, Object>> selectTotalByZzQualification();

    /**
     * 按照在职学位统计人数
     */
    public List<Map<String, Object>> selectTotalByZzDegree();
}
